## 开发规范

### 目录规范

- 目录名称统一小写，尽量短命名，如：apiserver
- 文件名称统一小写蛇形命名，如：xxx_demo.go
- 变量名相关统一驼峰命名，如：xxxDemo XxxDemo
- 前后端接口字段统一小驼峰,如：{"xxxDemo":"xxxx"}

### 代码规范

- 参考[`https://go.dev/doc/effective_go`](https://go.dev/doc/effective_go)
- 对于业务代码的注释请优先使用中文母语

### 接口规范

- 返回参数约定

```json
{
    "code":0,
    "msg":"success",
    "data":{
        
    }
}

```

```json
{
    "code": 120001,
    "msg":"xxxxxxxxxx",
    "data":null
}
```

### 错误码规范

- 错误码常量命名需以Err开头
- 常量的注释信息格式要求：// <http状态码> | <错误信息> | <详细信息>
- 注意：<错误信息>为TmpMsg时，将使用动态的错误信息返回

## 其他规范

### 文档规范

- api接口文档，统一写在`飞书文档`，每个接口至少包含如下说明：
    - 通用说明
    - 接口描述
    - 请求方法
    - 请求参数说明
    - 输出参数说明
    - 错误码描述
    - 请求示例

### commit规范

- git commit时需标识类别：
    - feat:<新增功能>
    - fix:<bug修复>
    - perf:<代码性能优化>
    - style:<格式变更>
    - refactor:<其他变更，如代码优化、变量名称修改、删除注释代码等>
    - test:<新增测试相关>
    - ci:<ci/cd相关配置或脚本变更>
    - docs:<文档更新>
    - chore:<其他>
- 合理使用git rebase

### 版本规范

- 版本号可按以下规则递增：
    - 主版本号（MAJOR）：当做了不兼容的 API 修改。
    - 次版本号（MINOR）：当做了向下兼容的功能性新增及修改。偶数为稳定版本，奇数为开发版本。
    - 修订号（PATCH）：当做了向下兼容的问题修正。
- 参考：https://semver.org/lang/zh-CN/

