package manage

import (
	"Cold_Logistic/internal/pkg/common/codex"
	"Cold_Logistic/internal/pkg/common/global"
	"Cold_Logistic/internal/server/application/carsrv"
	"Cold_Logistic/internal/server/infra/dao"
	"github.com/gin-gonic/gin"
	"gogs.baozhida.cn/Cold_Logistic_libs/pkg/contrib/core"
	"gogs.baozhida.cn/Cold_Logistic_libs/pkg/contrib/errors"
)

func (api Api) carPage(c *gin.Context) {
	req := carsrv.CarPageReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	srv := carsrv.NewCarService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.CarPage(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrQueryFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}

func (api Api) addCar(c *gin.Context) {
	req := carsrv.AddCarReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	if err := req.Validate(); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrParamValidate, "参数验证失败："))
		return
	}

	srv := carsrv.NewCarService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.AddCar(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrSaveFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}

func (api Api) updateCar(c *gin.Context) {
	req := carsrv.UpdateCarReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	if err := req.Validate(); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrParamValidate, "参数验证失败："))
		return
	}

	srv := carsrv.NewCarService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.UpdateCar(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrSaveFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}

func (api Api) driverLog(c *gin.Context) {
	req := carsrv.DriverLogReqVO{}
	if err := c.BindJSON(&req); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrBindJSON, ""))
		return
	}

	if err := req.Validate(); err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrParamValidate, "参数验证失败："))
		return
	}

	srv := carsrv.NewCarService(dao.NewDataStore(global.CommonConnectRepoInst.StoreDB))
	res, err := srv.DriverLog(c, req)
	if err != nil {
		core.WriteErrResponse(c, errors.WithCodeOnce(err, codex.ErrQueryFailed, ""))
		return
	}
	core.WriteResponse(c, nil, res)
}
