package swagger

import (
	"Cold_Logistic/internal/pkg/common/constant"
	"Cold_Logistic/internal/server/infra/models"
)

//使用swagegr过程中由于@Success注解在读取参数过程中无法读取到外部引用的结构体，所以在此处拷贝结构体供swagger注解使用

type PageListResponse struct {
	Total     int64       `json:"total"`     // 列表数据总数
	TotalPage int64       `json:"totalPage"` // 总页数
	Count     int         `json:"count"`     // 当前页总数
	List      interface{} `json:"list"`      // 列表数据信息
}
type LogisticListReqVO struct {
	UserTokey string `json:"userTokey"`
	Page      Page   `json:"page"`
	Search    struct {
		Name string `json:"name"`
	}
}
type OrderPageReqVO struct {
	Page   Page `json:"page"`
	Search struct {
		OrderNo             string                      `json:"orderNo"` // 订单号
		OrderStatus         []int                       `json:"orderStatus"`
		SearchDateTime      constant.SearchDateTimeType `json:"searchDateTime"`
		PlaceOrderStartTime models.MyTime               `json:"placeOrderStartTime"`
		PlaceOrderEndTime   models.MyTime               `json:"placeOrderEndTime"`
	}
}
type WarehouseOrderReqVO struct {
	Page   Page `json:"page"`
	Search struct {
		OrderNo   string        `json:"orderNo"`
		TimeStart models.MyTime `json:"timeStart"`
		TimeEnd   models.MyTime `json:"timeEnd"`
	}
}
type TaskPageReqVO struct {
	Page   Page `json:"page"`
	Status int  `json:"status"`
	Search struct {
		OrderNo string `json:"orderNo"`
	}
}
type LogisticPageReqVO struct {
	Page Page `json:"page"`
}
type AddressPageReqVO struct {
	Page        Page   `json:"page"`
	AddressType string `json:"addressType"` // 地址类型：sender-发货人 consignee-收货人
}
type AccountInfoVo struct {
	AccountId   int        `json:"accountId"`   // 账号ID
	AccountType int        `json:"accountType"` // 账号类型
	AccountUuid string     `json:"accountUuid"`
	Openid      string     `json:"openid"`      // 微信Openid
	Name        string     `json:"name"`        // 真实名称
	Role        string     `json:"role"`        // 角色：用户 司机 仓管
	Gender      string     `json:"gender"`      // 性别
	Phone       string     `json:"phone"`       // 电话
	CompanyName string     `json:"companyName"` // 公司
	Avatar      FileSource `json:"avatar"`      // 头像
	IsFirst     int        `json:"isFirst"`     // 是否首次登录，1-是 2-否
}
type FileSource struct {
	FileId   int    `json:"fileId"`
	FileCode string `json:"fileCode"`
	FileUrl  string `json:"fileUrl"`
	FileName string `json:"fileName"`
}
type SnDataListReqVO struct {
	UserTokey string `json:"userTokey"`
	SnId      string `json:"snId"`
	Page      Page   `json:"page"`
	Search    struct {
		TimeStart models.MyTime `json:"timeStart"` // 2023-03-14 00:00:00
		TimeEnd   models.MyTime `json:"timeEnd"`
	}
}
type BaseResponse struct {
	Code int `json:"code"` // 业务code码

	Message string `json:"msg"` // 提示信息

	Reference interface{} `json:"reference,omitempty"` // 关联信息

	Data interface{} `json:"data"` // 数据信息
}

type ListResponse struct {
	List interface{} `json:"list"` // 列表数据信息
}

type Page struct {
	Page   int    `json:"page"`   // 页码
	Offset int    `json:"offset"` // offset位移
	Size   int    `json:"size"`   // 每页最大加载条数
	Sort   string `json:"sort"`   // 排序（暂时不用）
}
